/*
 * File opening support.
 *
 * Copyright (C) 2021, 2022 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#include <stdlib.h>
#include <string.h>

#include "file_opening.h"



/* Obtain the identifier for any active parent directory for a path. */

long FileOpening::get_parent(const char *path, fileid_t *fileid)
{
    char *sep = strrchr(path, (int) '/');
    long err;

    /* For top-level paths, use the empty string to get the root directory.
       Otherwise, obtain the parent directory path to obtain the file
       identifier. */

    if (sep == NULL)
        err = get_fileid("", 0, fileid);
    else
    {
        char *parent = strndup(path, sep - path + 1);

        parent[sep - path] = '\0';
        err = get_fileid(parent, 0, fileid);
        free(parent);
    }

    return err;
}

// vim: tabstop=4 expandtab shiftwidth=4
